/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TCentralComponent.h"
#include"TImagesFactory.h"
#include "TTextEditor.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TCentralComponent::TCentralComponent() : Component("Central Component"),
                                         pTextEditor(0)
{
    pTextEditor = new TTextEditor();
    addAndMakeVisible(pTextEditor);

    ImageExit_png = ImageCache::getFromMemory(TImagesFactory::psExit_png, TImagesFactory::iExit_pngSize);
    ImageOpen_png = ImageCache::getFromMemory(TImagesFactory::psOpen_png, TImagesFactory::iOpen_pngSize);
    ImageCut_png = ImageCache::getFromMemory(TImagesFactory::psCut_png, TImagesFactory::iCut_pngSize);
    ImageCopy_png = ImageCache::getFromMemory(TImagesFactory::psCopy_png, TImagesFactory::iCopy_pngSize);
    ImagePaste_png = ImageCache::getFromMemory(TImagesFactory::psPaste_png, TImagesFactory::iPaste_pngSize);

    setSize (700, 400);
}
//---------------------------------------------------------------------
TCentralComponent::~TCentralComponent()
{
    // Удаляем дочерние виджеты
    // и обнуляем их указатели
    deleteAllChildren();
}
//---------------------------------------------------------------------
void TCentralComponent::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TCentralComponent::resized()
{
    pTextEditor->setBounds(15, 25, getWidth() - 30, getHeight() - 45);
}
//---------------------------------------------------------------------
const StringArray TCentralComponent::getMenuBarNames()
{
    // Создаются основные пункты меню
    StringArray sMenuNames;
    sMenuNames.add(tr("Файл"));
    sMenuNames.add(tr("Правка"));
    return sMenuNames;
}
//---------------------------------------------------------------------
void TCentralComponent::menuItemSelected(int iMenuItemID, int iTopLevelMenuIndex)
{
    // Обработчики команд меню
    switch(iMenuItemID)
    {
        // Если выбран пункт "Выход"...
        case FileQuit:
        {
            // Завершаем работу программы
            JUCEApplication::quit();
            break;
        }
        // Если выбран пункт "Открыть"...
        case FileOpen:
        {
            // Задаём в качестве стартовой директории для поиска файла папку "Документы" текущего пользователя
            File InitialFile;
            InitialFile = InitialFile.getSpecialLocation(File::userDocumentsDirectory);

            // В качестве фильтра поиска файлов задаём текстовый файл
            WildcardFileFilter TextFileFilter("*.txt", String::empty, tr("Текстовые файлы"));

            // Компонент для отображения списка файлов
            FileBrowserComponent FileBrowser(FileBrowserComponent::openMode | FileBrowserComponent::canSelectFiles, 
                                             InitialFile, & TextFileFilter, NULL);

            // Диалог для отображения FileBrowser
            FileChooserDialogBox OpenFileDialog(tr("Открыть файл"), 
                                                tr("Выберите текстовый файл, который вы хотите открыть..."), 
                                                FileBrowser, false, Colours::azure);
            OpenFileDialog.setSize(600, 400);

            // Если пользователь выбрал файл...
            if(OpenFileDialog.show())
            {
                // открываем его
                InitialFile = FileBrowser.getSelectedFile(0);
                FileInputStream Input(InitialFile);
                pTextEditor->setText(Input.readEntireStreamAsString());
            }
        }
        // Если выбран пункт "Вырезать"...
        case EditCut:
        {
            // Работает аналогично pTextEditor->cut();
            SystemClipboard::copyTextToClipboard(pTextEditor->getHighlightedText());
            pTextEditor->insertTextAtCaret(String::empty);
            break;
        }
        // Если выбран пункт "Копировать"...
        case EditCopy:
        {
            // Работает аналогично  pTextEditor->copy();
            SystemClipboard::copyTextToClipboard(pTextEditor->getHighlightedText());
            break;
        }
        // Если выбран пункт "Вставить"...
        case EditPaste:
        {
            // Работает аналогично pTextEditor->paste();
            pTextEditor->insertTextAtCaret(SystemClipboard::getTextFromClipboard());
            break;
        }
    }
}
//---------------------------------------------------------------------
const PopupMenu TCentralComponent::getMenuForIndex(int iIndex, const String& sMenuName)
{
    // Создаём выпадающее меню
    PopupMenu Menu;

    switch(iIndex)
    {
        // Индекс 0 соответствует пункту меню "Файл"
        // (см. getMenuBarNames)
        case 0:
        {
            // Добавляем новые пункты в меню "Файл"
            Menu.addItem(FileOpen, tr("Открыть..."), true, false, ImageOpen_png);
            // Добавляем разделитель
            Menu.addSeparator();
            Menu.addItem(FileQuit, tr("Выход"), true, false, ImageExit_png);
            break;
        }
        case 1:
        {
            Menu.addItem(EditCut, tr("Вырезать"), true, false, ImageCut_png);
            Menu.addItem(EditCopy, tr("Копировать"), true, false, ImageCopy_png);
            Menu.addItem(EditPaste, tr("Вставить"), true, false, ImagePaste_png);
            break;
        }
    }

    return Menu;
}
//---------------------------------------------------------------------
